/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize;

import grandeszapatos.getsize.database.DataAdapter;

import java.util.ArrayList;
import java.util.HashMap;

import android.app.ListActivity;
import android.content.Context;
import android.database.Cursor;
import android.os.Bundle;
import android.widget.SimpleAdapter;
import android.widget.TextView;
import android.widget.Toast;

public class ResultActivity extends ListActivity {

	// Establecemos los nombres de las columnas
	public final static String KEY_ID = "_id";
	public final static String KEY_CM = "cm";
	public final static String KEY_FABRICANTE = "Fabricante";
	public final static String KEY_TALLA_FABRICANTE = "TallaFabricante";
	public final static String KEY_TIPO_TALLA = "TipoTalla";
	public final static String KEY_SEXO = "Sexo";

	// Mantenemos un Array de elementos en la que podremos guardar
	// ms informacin de la que mostraremos en el listado
	ArrayList<HashMap<String, String>> Resultados;

	// Con los siguientes Arrays establecemos la correspondencia
	// entre los elementos del Array de HashMaps de eventos (from)
	// con los elementos del diseo en XML de cada una de las filas (to)
	String[] from = new String[] { "Fabricante", "TallaFabricante" };

	int[] to = new int[] { R.id.fabricante, R.id.tallafabricante };

	@Override
	public void onCreate(Bundle savedInstanceState) {

		super.onCreate(savedInstanceState);
		// Establecemos el diseo principal de la Actividad
		setContentView(R.layout.list_results);
		this.setTitle();
		// Este mtodo de obtencin de elementos puede cambiarse por cualquier
		// otro
		// como leerlos de una BBDD o de un servidor web con JSON
		ArrayList<String[]> lista = new ArrayList<String[]>();

		Bundle extras = getIntent().getExtras();
		float cm = extras.getFloat("cm");
		int sexo = extras.getInt("sexo");
		Context urContext = getApplicationContext();
		DataAdapter mDbHelper = new DataAdapter(urContext);
		mDbHelper.createDatabase();
		mDbHelper.open();
		Cursor testdata = mDbHelper.getData(cm, sexo);

		if (testdata.moveToFirst() == false) {
			// el cursor est vaco
			Toast.makeText(getApplicationContext(), R.string.no_result_found,
					Toast.LENGTH_LONG).show();
			this.onDestroy();
		}

		// Obtenemos los ndices de las columnas
		int FabricanteColumn = testdata.getColumnIndex(KEY_FABRICANTE);
		int TallaColumn = testdata.getColumnIndex(KEY_TALLA_FABRICANTE);

		// Recorremos el cursor
		for (testdata.moveToFirst(); !testdata.isAfterLast(); testdata
				.moveToNext()) {
			String Fabricante = testdata.getString(FabricanteColumn);
			String TallaFabricante = testdata.getString(TallaColumn);

			String[] Resultado = { Fabricante, TallaFabricante };

			lista.add(Resultado);

		}

		// Transformamos los elementos String[] en HashMap para
		// posteriormente incluirlos en el Array Global que se utilizar
		// para rellenar la lista
		Resultados = new ArrayList<HashMap<String, String>>();
		for (String[] evento : lista) {
			HashMap<String, String> datosResultado = new HashMap<String, String>();

			// Aqu es dnde utilizamos las referencias creadas inicialmente
			// en el elemento "from"
			datosResultado.put("Fabricante", evento[0]);
			datosResultado.put("TallaFabricante", evento[1]);

			Resultados.add(datosResultado);
		}
		// Una vez tenemos toda la informacin necesaria para rellenar la lista
		// creamos un elemento que nos facilitar la tarea:
		// SimpleAdapter(Actividad, Array de HashMap con elementos, Fichero XML
		// del
		// diseo de cada fila, Cadenas del HashMap, Ids del Fichero XML del
		// diseo de cada fila)
		SimpleAdapter ListadoAdapter = new SimpleAdapter(this, Resultados,
				R.layout.row, from, to);
		setListAdapter(ListadoAdapter);
	}

	private void setTitle() {
		((TextView) this.findViewById(R.id.title_dashboard))
				.setText(R.string.results);
	}
}
