/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize.measure;

import grandeszapatos.getsize.setting.SettingConst;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;

public class LengthOverlayView extends MeasureOverlayView {

	RectF dst;

	public LengthOverlayView(Context ctx, CalculateListener calclistener) {
		super(ctx, calclistener);
	}

	@Override
	float calculate() {
		float f1 = 0.0F;
		float f2 = 0.0F;
		switch (this.axis) {
		case 0:
			f1 = Math.abs(this.barX[0] - this.barX[1]);
			f2 = Math.abs(this.barX[2] - this.barX[3]);
			break;
		case 1:
			f1 = Math.abs(this.barY[0] - this.barY[1]);
			f2 = Math.abs(this.barY[2] - this.barY[3]);
		}

		float f3 = f2 * this.ruler.getSize() / f1;
		switch (this.ruler.getUnit()) {
		case 0:
		default:
			break;
		case 1:
			f3 *= SettingConst.Unit.INCH_COEFFICIENT;
			break;
		case 2:
			f3 *= SettingConst.Unit.MILI_COEFFICIENT;
		}

		if (this.calculateListener != null) {
			this.calculateListener.setResult(f3, this.unit);
		}

		return f3;
	}

	private void drawBrokenLine(Canvas cnv1, float f1, float f2, float f3,
			float f4, Paint pnt1) {
		double f5 = Math.atan((Math.abs(f4 - f2) / Math.abs(f3 - f1)));
		float f6;
		if (Math.abs(f3 - f1) == 0.0F) {
			f6 = 0.0F;
		} else {
			f6 = (float) (15 * Math.cos(f5));
		}

		float f7;
		if (Math.abs(f4 - f2) == 0.0F) {
			f7 = 0.0F;
		} else {
			f7 = (float) (15 * Math.sin(f5));
		}

		while (true) {
			float f8 = f1 + f6;
			float f9 = f2 + f7;
			cnv1.drawLine(f1, f2, f8, f9, pnt1);
			if (f1 + f6 > f3 || f2 + f7 > f4) {
				return;
			}

			f1 = f8 + f6;
			f2 = f9 + f7;
		}
	}

	@Override
	void drawLines(Canvas cnv1) {
		if (this.axis == 0) {
			for (int i = 0; i < 4; ++i) {
				if (i < 2) {
					if (this.captureSolidLine) {
						continue;
					}

					cnv1.drawLine(this.barX[i], 0.0F, this.barX[i],
							this.getHeight(), this.paint);
					this.dst = new RectF(this.barX[i], 0.0F, this.barX[i]
							+ (this.ruler.getThumbnail().getWidth() / 3),
							(this.ruler.getThumbnail().getHeight() / 3));
					cnv1.drawBitmap(this.ruler.getThumbnail(), (Rect) null,
							this.dst, (Paint) null);
				} else {
					this.drawBrokenLine(cnv1, this.barX[i], 0.0F, this.barX[i],
							this.getHeight(), this.paint);
				}

				if (this.showLockNo && !this.captureDefa) {
					cnv1.drawText(String.valueOf(i + 1), this.barX[i] - 1.0F,
							(1 + this.getHeight()), this.verge);
					cnv1.drawText(String.valueOf(i + 1), this.barX[i],
							this.getHeight(), this.paint);
				}
			}
		} else {
			for (int i = 0; i < 4; ++i) {
				if (i < 2) {
					cnv1.drawLine(0.0F, this.barY[i], this.getWidth(),
							this.barY[i], this.paint);
					this.dst = new RectF(0.0F, this.barY[i], (this.ruler
							.getThumbnail().getWidth() / 3), this.barY[i]
							+ (this.ruler.getThumbnail().getHeight() / 3));
					cnv1.drawBitmap(this.ruler.getThumbnail(), (Rect) null,
							this.dst, (Paint) null);
				} else {
					this.drawBrokenLine(cnv1, 0.0F, this.barY[i],
							this.getWidth(), this.barY[i], this.paint);
				}

				if (this.showLockNo) {
					cnv1.drawText(String.valueOf(i + 1), this.getWidth()
							- this.paint.getTextSize() - 1.0F,
							1.0F + this.barY[i], this.verge);
					cnv1.drawText(String.valueOf(i + 1), this.getWidth()
							- this.paint.getTextSize(), this.barY[i],
							this.paint);
				}
			}
		}

	}

	@Override
	protected void onDraw(Canvas cnv1) {
		super.onDraw(cnv1);
	}

	@Override
	int setCatchingBar(float f1, float f2) {
		int i1;
		int i2 = 0;
		label34: switch (this.axis) {
		case 0:
			while (true) {
				if (i2 >= 4) {
					break label34;
				}

				if (Math.abs(f1 - this.barX[i2]) < 20.0F && !this.lockList[i2]) {
					this.isCatching = true;
					i1 = i2;
					return i1;
				}

				++i2;
			}
		case 1:
			while (i2 < 4) {
				if (Math.abs(f2 - this.barY[i2]) < 20.0F && !this.lockList[i2]) {
					this.isCatching = true;
					i1 = i2;
					return i1;
				}

				++i2;
			}
		}

		i1 = -1;
		return i1;
	}
}
