/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize.measure;

import grandeszapatos.getsize.R;
import grandeszapatos.getsize.ResultActivity;
import grandeszapatos.getsize.dialog.InputsexDialog;
import grandeszapatos.getsize.setting.SettingConfig;
import grandeszapatos.getsize.setting.SettingConfigManager;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

import android.app.Activity;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

public class MeasureActivity extends Activity implements
		CompoundButton.OnCheckedChangeListener {

	private String mCurrentPhotoPath;
	private static final String JPEG_FILE_PREFIX = "IMG_";
	private static final String JPEG_FILE_SUFFIX = ".jpg";

	private InputsexDialog dialogsex;

	private ImageView imageView = null;
	private LinearLayout lockLayoit;
	private CheckBox lock_01;
	private CheckBox lock_02;
	private CheckBox lock_03;
	private CheckBox lock_04;
	private MeasureOverlayView measureOverlayView = null;
	private ResultTextView resultTextView = null;
	private ImageView rulerImage = null;
	private TextView rulerName = null;
	private SettingConfig settingConfig;

	private float cm = 0;

	private final InputsexDialog.OnChlickListener onChlickListener = new InputsexDialog.OnChlickListener() {

		public void OnChlickPositive(Dialog dialog1) {
			showResults(cm, 1);
			hideInputsexDialog();

		}

		public void OnClickNegative(Dialog dialog1) {
			showResults(cm, 0);
			hideInputsexDialog();

		}

	};

	private File createImageFile() throws IOException {
		String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss")
				.format(new Date());
		String imageFileName = JPEG_FILE_PREFIX + timeStamp + "_";
		File albumF = getAlbumDir();
		File imageF = File.createTempFile(imageFileName, JPEG_FILE_SUFFIX,
				albumF);
		return imageF;
	}

	private void dispatchTakePictureIntent(int actionCode) {

		Intent takePictureIntent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);

		ComponentName cn = takePictureIntent
				.resolveActivity(getPackageManager());

		switch (actionCode) {
		case 1:
			File f = null;

			try {
				f = setUpPhotoFile();
				mCurrentPhotoPath = f.getAbsolutePath();
				takePictureIntent.putExtra(MediaStore.EXTRA_OUTPUT,
						Uri.fromFile(f));
			} catch (IOException e) {
				e.printStackTrace();
				f = null;
				mCurrentPhotoPath = null;
			}
			break;

		default:
			break;
		}

		if (cn == null) {
			// no hay activity para realizar la accion
		} else {

			startActivityForResult(takePictureIntent, actionCode);
		}

	}

	private File getAlbumDir() {

		File storageDir = null;
		File sdCard = null;
		sdCard = Environment.getExternalStorageDirectory();

		if (Environment.MEDIA_MOUNTED.equals(Environment
				.getExternalStorageState())) {

			storageDir = new File(sdCard.getAbsolutePath() + "/TallaZapatos");

			if (storageDir != null) {
				if (!storageDir.mkdirs()) {
					if (!storageDir.exists()) {
						Log.d(getString(R.string.app_name),
								"Fallo al crear el directorio");
						return null;
					}
				}
			}

		} else {
			Log.v(getString(R.string.app_name),
					"Almacenamiento Externo no montado.");
		}

		return storageDir;
	}

	private void handleBigCameraPhoto() {

		if (mCurrentPhotoPath != null) {
			setPic();
			mCurrentPhotoPath = null;
		}

	}

	void hideInputsexDialog() {
		this.dialogsex.hide();
	}

	@Override
	protected void onActivityResult(int paramInt1, int paramInt2,
			Intent paramIntent) {
		handleBigCameraPhoto();
	}

	public void onCheckedChanged(CompoundButton paramCompoundButton,
			boolean paramBoolean) {
		switch (paramCompoundButton.getId()) {

		case R.id.measure_lock_btn01:
			this.measureOverlayView.setLock(0, paramBoolean);
		case R.id.measure_lock_btn02:
			this.measureOverlayView.setLock(1, paramBoolean);
		case R.id.measure_lock_btn03:
			this.measureOverlayView.setLock(2, paramBoolean);
		case R.id.measure_lock_btn04:
			this.measureOverlayView.setLock(3, paramBoolean);
		default:

		}
	}

	public void onClickLock(View paramView) {
		this.lockLayoit.setVisibility(0);
		this.measureOverlayView.setShowLockNo(0);
		return;
	}

	public void onClickOk(View paramView) {

		cm = Float.parseFloat(this.resultTextView.getText().toString()
				.replace("cm", ""));

		showInputsexDialog(cm);

	}

	@Override
	public void onCreate(Bundle paramBundle) {
		super.onCreate(paramBundle);
		setContentView(R.layout.measure);
		this.settingConfig = SettingConfigManager.get(getApplicationContext());
		this.imageView = ((ImageView) findViewById(R.id.measure_pict));
		this.imageView.setScaleType(ImageView.ScaleType.CENTER_CROP);
		this.rulerImage = ((ImageView) findViewById(R.id.measure_ruler_image));
		this.rulerName = ((TextView) findViewById(R.id.measure_ruler_name));
		this.resultTextView = ((ResultTextView) findViewById(R.id.measure_result));
		this.resultTextView.setTextColor(this.settingConfig.getInt("color",
				16777215));
		getIntent().getExtras().getInt("action_flags");
		this.lockLayoit = ((LinearLayout) findViewById(R.id.measure_lock_list));
		this.lock_01 = ((CheckBox) findViewById(R.id.measure_lock_btn01));
		this.lock_01.setVisibility(1);
		this.lock_01.setOnCheckedChangeListener(this);
		this.lock_02 = ((CheckBox) findViewById(R.id.measure_lock_btn02));
		this.lock_02.setVisibility(0);
		this.lock_02.setOnCheckedChangeListener(this);
		this.lock_03 = ((CheckBox) findViewById(R.id.measure_lock_btn03));
		this.lock_03.setVisibility(0);
		this.lock_03.setOnCheckedChangeListener(this);
		this.lock_04 = ((CheckBox) findViewById(R.id.measure_lock_btn04));
		this.lock_04.setVisibility(0);
		this.lock_04.setOnCheckedChangeListener(this);
		this.measureOverlayView = new LengthOverlayView(
				getApplicationContext(), this.resultTextView);
		((RelativeLayout) findViewById(R.id.baselayout)).addView(
				this.measureOverlayView, 1);
		dispatchTakePictureIntent(1);
		return;
	}

	@Override
	public boolean onCreateOptionsMenu(Menu paramMenu) {
		return true;
	}

	@Override
	public boolean onMenuItemSelected(int paramInt, MenuItem paramMenuItem) {
		return true;
	}

	@Override
	protected void onPause() {
		super.onPause();
	}

	@Override
	public boolean onPrepareOptionsMenu(Menu paramMenu) {
		return super.onPrepareOptionsMenu(paramMenu);
	}

	@Override
	protected void onResume() {
		int i = this.settingConfig.getInt("color", 268435455);
		this.measureOverlayView.setColor(i);
		this.resultTextView.setTextColor(i);
		this.measureOverlayView.setRuler(this.settingConfig.getString("ruler",
				"Tarjeta(Largo)"));
		if (this.measureOverlayView.hasRulerThumbnail()) {
			this.rulerImage.setImageBitmap(this.measureOverlayView
					.getRulerThumbnail());
			this.rulerImage.setVisibility(0);
			this.rulerName.setVisibility(4);
		}
		while (true) {
			super.onResume();

			this.rulerName.setText(this.measureOverlayView.getRulerName());
			this.rulerName.setTextColor(i);
			this.rulerName.setVisibility(0);
			this.rulerImage.setVisibility(4);
			return;
		}
	}

	private void setPic() {

		// Obtener el tamao del ImageView

		int targetW = this.imageView.getWidth();
		int targetH = this.imageView.getHeight();

		// Obtener el tamao de la imagen
		BitmapFactory.Options bmOptions = new BitmapFactory.Options();
		bmOptions.inJustDecodeBounds = true;
		BitmapFactory.decodeFile(mCurrentPhotoPath, bmOptions);
		int photoW = bmOptions.outWidth;
		int photoH = bmOptions.outHeight;

		// detectar que parte tiene que ser reducida menos
		int scaleFactor = 1;
		if ((targetW > 0) || (targetH > 0)) {
			scaleFactor = Math.min(photoW / targetW, photoH / targetH);
		}

		// configurar las opciones de escala del bitmap
		bmOptions.inJustDecodeBounds = false;
		bmOptions.inSampleSize = scaleFactor;
		bmOptions.inPurgeable = true;

		// decodificar el fichero jpeg en el bitmap
		Bitmap bitmap = BitmapFactory.decodeFile(mCurrentPhotoPath, bmOptions);

		// asociar el bitmap con el imageview
		this.imageView.setImageBitmap(bitmap);
		this.imageView.setVisibility(View.VISIBLE);

		Toast.makeText(getApplicationContext(), R.string.toast_howto_length,
				Toast.LENGTH_LONG).show();

	}

	private File setUpPhotoFile() throws IOException {

		File f = createImageFile();
		mCurrentPhotoPath = f.getAbsolutePath();

		return f;
	}

	void showInputsexDialog(float f) {
		this.dialogsex = new InputsexDialog(this, this.onChlickListener);
		this.dialogsex.setTitle(R.string.dialog_sex_title);
		this.dialogsex.show();

	}

	void showResults(float cm, int sexo) {

		Intent ResultActivity = new Intent(getBaseContext(),
				ResultActivity.class);
		ResultActivity.putExtra("cm", cm);
		ResultActivity.putExtra("sexo", sexo);
		startActivity(ResultActivity);
	}

}
