/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize.measure;

import grandeszapatos.getsize.R;
import grandeszapatos.getsize.setting.SettingConfig;
import grandeszapatos.getsize.setting.SettingConfigManager;
import grandeszapatos.getsize.setting.ruler.Ruler;
import grandeszapatos.getsize.setting.ruler.RulerConfig;
import grandeszapatos.getsize.setting.ruler.RulerConfigManager;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.view.MotionEvent;
import android.view.View;

public abstract class MeasureOverlayView extends View {

	float angle;
	int axis;
	float[] barX;
	float[] barY;
	CalculateListener calculateListener;
	protected boolean captureDefa;
	protected boolean captureSolidLine;
	Bitmap catchHand;
	int catchingBar;
	boolean isCatching;
	boolean[] lockList;
	Bitmap locked;
	private final Matrix matrix;
	Paint paint;
	Ruler ruler;
	private final RulerConfig rulerConfig;
	private final SettingConfig settingConfig;
	boolean showLockNo;
	int unit;
	Paint verge;

	public MeasureOverlayView(Context ctx1, CalculateListener calclist1) {
		super(ctx1);
		float[] var3 = new float[] { 100.0F, 200.0F, 300.0F, 400.0F };
		this.barX = var3;
		float[] var4 = new float[] { 50.0F, 100.0F, 150.0F, 200.0F };
		this.barY = var4;
		this.lockList = new boolean[4];
		this.captureDefa = false;
		this.captureSolidLine = false;
		this.calculateListener = calclist1;
		this.settingConfig = SettingConfigManager.get(ctx1);
		this.rulerConfig = RulerConfigManager.get(ctx1);
		this.paint = new Paint();
		this.paint.setTextSize(30.0F);
		this.setColor(this.settingConfig.getInt("color", 16777215));
		this.paint.setStrokeWidth(2.0F);
		this.verge = new Paint();
		this.verge.setTextSize(30.0F);
		this.verge.setColor(-16777216);
		this.matrix = new Matrix();
		this.matrix.postScale(0.75F, 0.75F);
		this.catchHand = BitmapFactory.decodeResource(ctx1.getResources(),
				R.drawable.hand);
		this.locked = BitmapFactory.decodeResource(ctx1.getResources(),
				R.drawable.lock_icon);
		this.setRuler(this.settingConfig.getString("ruler", "Tarjeta(Largo)"));
		this.setunit(Integer.parseInt(this.settingConfig.getString("unit", "0")));
		this.setAxis(Integer.parseInt(this.settingConfig.getString("axis", "0")));
		this.setAngle(this.settingConfig.getFloat("angle", 26.5F));
	}

	abstract float calculate();

	abstract void drawLines(Canvas cnv1);

	public void finish4Capture() {
		this.captureDefa = false;
		this.captureSolidLine = false;
		this.invalidate();
	}

	public String getRulerName() {
		return this.ruler.getName();
	}

	public Bitmap getRulerThumbnail() {
		return this.ruler.getThumbnail();
	}

	public boolean hasRulerThumbnail() {
		return this.ruler.hasThumbnail(this.getContext());
	}

	@Override
	protected void onDraw(Canvas cnv1) {
		super.onDraw(cnv1);
		cnv1.drawColor(0);
		this.drawLines(cnv1);
		if (this.isCatching) {
			switch (this.axis) {
			case 0:
				cnv1.drawBitmap(this.catchHand,
						this.barX[this.catchingBar] - 12.0F,
						(this.getHeight() / 2), (Paint) null);
				break;
			case 1:
				cnv1.drawBitmap(this.catchHand, (this.getWidth() / 2),
						this.barY[this.catchingBar] - 15.0F, (Paint) null);
			}
		}

		if (!this.captureDefa) {
			for (int lock = 0; lock < 4; ++lock) {
				if (this.lockList[lock]) {
					switch (this.axis) {
					case 0:
						cnv1.drawBitmap(this.locked, this.barX[lock] - 10.0F,
								(this.getHeight() / 2), (Paint) null);
						break;
					case 1:
						cnv1.drawBitmap(this.locked, (this.getWidth() / 2),
								this.barY[lock] - 10.0F, (Paint) null);
					}
				}
			}

			this.calculate();
		}

	}

	@Override
	public boolean onTouchEvent(MotionEvent mev1) {
		float x = mev1.getX();
		float y = mev1.getY();
		if (this.isCatching) {
			switch (mev1.getAction()) {
			case 0:
			case 2:
				this.setLinePosition(x, y);
				break;
			case 1:
				this.isCatching = false;
			}
		} else {
			this.catchingBar = this.setCatchingBar(x, y);
		}

		this.invalidate();
		return true;
	}

	public void set4Capture(boolean b) {
		this.captureDefa = true;
		this.captureSolidLine = b;
		this.invalidate();
	}

	void setAngle(float angle) {
		this.angle = angle;
		this.invalidate();
	}

	void setAxis(int axis) {
		this.axis = axis;
		switch (axis) {
		case 0:
			float[] af1 = new float[] { 100.0F, 200.0F, 300.0F, 400.0F };
			this.barX = af1;
			break;
		case 1:
			float[] af2 = new float[] { 50.0F, 100.0F, 150.0F, 200.0F };
			this.barY = af2;
		}

		this.invalidate();
	}

	abstract int setCatchingBar(float f1, float f2);

	void setColor(int color) {
		this.paint.setColor(color);
		this.invalidate();
	}

	void setLinePosition(float x, float y) {
		switch (this.axis) {
		case 0:
			this.barX[this.catchingBar] = x;
			break;
		case 1:
			this.barY[this.catchingBar] = y;
		}

	}

	void setLock(int lock, boolean val) {
		this.lockList[lock] = val;
		this.invalidate();
	}

	void setRuler(String rulerstr) {
		this.ruler = this.rulerConfig.getRuler(this.getContext(), rulerstr);
		this.invalidate();
	}

	public void setShowLockNo(int i) {
		boolean b;
		if (i == 0) {
			b = true;
		} else {
			b = false;
		}

		this.showLockNo = b;
		this.invalidate();
	}

	void setunit(int unit) {
		this.unit = unit;
		this.invalidate();
	}
}
