/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize.setting.ruler;

import grandeszapatos.getsize.R;
import grandeszapatos.getsize.util.BitmapUtil;
import grandeszapatos.getsize.util.FileUtil;

import java.util.Arrays;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.graphics.Bitmap;

public class RulerConfig {

	private final String DELI = ":";
	private SharedPreferences pref = null;

	RulerConfig(Context ctx, String prefs) {
		this.pref = ctx.getSharedPreferences(prefs, 0);
		if (this.getAll().size() == 0) {
			this.addRuler(ctx, "Tarjeta(Largo)", 8.6F, 0, BitmapUtil
					.resizeBitmap(
							BitmapUtil.res2bmp(ctx, R.drawable.card_long), 107,
							107));
		}
	}

	public void addRuler(Context ctx, String key, float f, int i, Bitmap bmp) {
		if (!this.containsKey(key)) {
			this.putString(key, this.getLength() + this.DELI + f + this.DELI
					+ i);
			if (bmp != null) {
				FileUtil.saveThumbnail(ctx, key, bmp);
			}
		}

	}

	public void alterRuler(Context ctx, String rulername, float f, int i,
			Bitmap bmp) {
		Ruler var6 = this.getRuler(ctx, rulername);
		this.putString(rulername, var6.getNo() + this.DELI + f + this.DELI + i);
		if (var6.getThumbnail() != null) {
			FileUtil.deleteThumbnail(ctx, rulername);
		}

		if (bmp != null) {
			FileUtil.saveThumbnail(ctx, rulername, bmp);
		}

	}

	public void alterRulerName(Context ctx, String rulername,
			String newrulername) {
		Ruler var4 = this.getRuler(ctx, rulername);
		this.remove(rulername);
		this.putString(newrulername, var4.getNo() + this.DELI + var4.getSize()
				+ this.DELI + var4.getUnit());
		if (var4.getThumbnail() != null) {
			FileUtil.renameThumbnail(ctx, rulername, newrulername);
		}

	}

	public boolean containsKey(String key) {
		return this.pref.contains(key);
	}

	public void deleteRuler(Context ctx, String rulername) {
		this.remove(rulername);
		if (FileUtil.getThumbnail(ctx, rulername) != null) {
			FileUtil.deleteThumbnail(ctx, rulername);
		}

		Ruler[] ruler = this.getRulerList(ctx);
		int length = ruler.length;

		for (int i = 0; i < length; ++i) {
			this.putString(
					ruler[i].getName(),
					i + this.DELI + ruler[i].getSize() + this.DELI
							+ ruler[i].getUnit());
		}

	}

	private Map getAll() {
		return this.pref.getAll();
	}

	private int getLength() {
		return this.getAll().size();
	}

	public Ruler getRuler(Context ctx, String rulername) {
		String[] str = this.getString(rulername, (String) null)
				.split(this.DELI);
		return new Ruler(ctx, rulername, Integer.parseInt(str[0]),
				Float.parseFloat(str[1]), Integer.parseInt(str[2]));
	}

	public Ruler[] getRulerList(Context ctx) {
		Map m = this.getAll();
		Ruler[] ruler = new Ruler[m.size()];
		int i = 0;

		for (Iterator iter = m.entrySet().iterator(); iter.hasNext(); ++i) {
			ruler[i] = this.getRuler(ctx,
					(String) ((Entry) iter.next()).getKey());
		}
		Arrays.sort(ruler);
		return ruler;
	}

	private String getString(String s1, String s2) {
		return this.pref.getString(s1, s2);
	}

	private void putString(String s1, String s2) {
		Editor edt = this.pref.edit();
		edt.putString(s1, s2);
		edt.commit();
	}

	private void remove(String s) {
		Editor edt = this.pref.edit();
		edt.remove(s);
		edt.commit();
	}
}
