/*******************************************************************************
 * Copyright (c) 2013 Javier Finez de Dios.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl.html
 ******************************************************************************/
package grandeszapatos.getsize.util;

import java.io.InputStream;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.drawable.BitmapDrawable;
import android.net.Uri;

public class BitmapUtil {

	public static Bitmap cutBitmap(Bitmap bmpin, int i1, int i2, int i3, int i4) {
		Bitmap bmpout = Bitmap.createBitmap(i3, i4, Config.ARGB_8888);
		(new Canvas(bmpout)).drawBitmap(bmpin, (-i1), (-i2), (Paint) null);
		return bmpout;
	}

	public static Bitmap data2bmp(byte[] data, int i1, int i2) {
		Options opt = new Options();
		opt.inJustDecodeBounds = true;
		BitmapFactory.decodeByteArray(data, 0, data.length, opt);
		int size = Math.max(1 + opt.outWidth / i1, 1 + opt.outHeight / i2);
		opt.inJustDecodeBounds = false;
		opt.inSampleSize = size;
		return BitmapFactory.decodeByteArray(data, 0, data.length, opt);
	}

	public static Bitmap res2bmp(Context ctx, int i) {
		return BitmapFactory.decodeResource(ctx.getResources(), i);
	}

	public static Bitmap resizeBitmap(Bitmap bmpin, int i1, int i2) {
		Bitmap bmpout = Bitmap.createBitmap(i1, i2, Config.ARGB_8888);
		Canvas cnv = new Canvas(bmpout);
		BitmapDrawable var5 = new BitmapDrawable(bmpin);
		var5.setBounds(0, 0, i1, i2);
		var5.draw(cnv);
		return bmpout;
	}

	public static Bitmap rotateBitmap90(Bitmap bmpin) {
		int width = bmpin.getWidth();
		int height = bmpin.getHeight();
		Bitmap bmpout = Bitmap.createBitmap(height, width, Config.ARGB_8888);
		Canvas cnv = new Canvas(bmpout);
		cnv.rotate(90.0F, 0.0F, 0.0F);
		cnv.drawBitmap(bmpin, 0.0F, (-height), (Paint) null);
		return bmpout;
	}

	public static Bitmap uri2bmp2(Context ctx, Uri uri, int i1, int i2) {
		InputStream stream = null;

		Bitmap bmp1;
		Bitmap bmp2;
		try {
			Options opts = new Options();
			opts.inJustDecodeBounds = true;
			stream = ctx.getContentResolver().openInputStream(uri);
			BitmapFactory.decodeStream(stream, (Rect) null, opts);
			stream.close();
			int size = Math
					.min(1 + opts.outWidth / i1, 1 + opts.outHeight / i2);
			Options opts2 = new Options();
			opts2.inJustDecodeBounds = false;
			opts2.inSampleSize = size;
			stream = ctx.getContentResolver().openInputStream(uri);
			bmp2 = BitmapFactory.decodeStream(stream, (Rect) null, opts2);
			stream.close();
		} catch (Exception ex) {
			if (stream != null) {
				try {
					stream.close();
				} catch (Exception ex2) {
					;
				}
			}

			bmp1 = null;
			return bmp1;
		}

		bmp1 = bmp2;
		return bmp1;
	}
}
